# Malware analysis

- Reverse engineering of a malware program
- Purpose is to
  - determine how the malware works
  - assess the potential damage it could cause
- Helps find and remove the infections that exist in a system through using designed tools an techniques.

## Malware analysis types

### Static malware analysis

- Analyzing the malware without running or installing it
- Malware's binary code is examined
- Checks for any data structures or function calls that have malicious behavior.

### Dynamic malware analysis

- Requires the malware program to be running in a monitored environment such as sandbox or a virtual machine.
- Helps in understanding how the malware works by monitoring its activities on the system.

#### Windows integrity monitoring

##### Port monitoring

- Involves monitoring services running on different ports.
- Features can include
  - analytics for packet rates, CPU, power, and bandwidth of ports
  - mirroring the traffic from one port to another
- 📝 Tools include
  - `netstat` (terminal)
    - Displays network connections, available on many OSes
    - E.g. `netstat -an` to display all connections and listening ports (`-a`) in a numerical format `-n`
  - [TCPView](https://docs.microsoft.com/en-us/sysinternals/downloads/tcpview) (GUI)
    - Windows tool to enumerate network connections and owner processes
    - Refreshes automatically
  - [CurrPorts](https://www.nirsoft.net/utils/cports.html) (GUI)
    - View open ports and connections per process on Windows
- See also • [Common ports to scan | Scanning networks](./03-scanning-networks/../../03-scanning-networks/scanning-networks-overview.md#common-ports-to-scan) • [Common ports and services to enumerate](./../04-enumeration/enumeration-overview.md#common-ports-and-services-to-enumerate)

##### Process monitoring

- Use e.g. [Process Monitor](https://docs.microsoft.com/en-us/sysinternals/downloads/procmon) to see what processes malware starts
- Built-in `sc` command provides all sorts of information about running services on a Windows machine.
  - E.g. `sc query` to lists the running services

##### Registry monitoring

- Registry contains information, settings, options, and other values for programs and hardware installed on all versions of Microsoft Windows operating systems.
- Malware modifies registry including keys such as `Run`, `RunServices`, `RunOnce`, `RunServicesOnce`, `HKEY_CLASSES_ROOT\exefile\shell\open\command "%1" %*.`
- Use native `regedit` or e.g. [RegScanner](https://www.nirsoft.net/utils/regscanner.html), [Registry Viewer](https://accessdata.com/product-download/registry-viewer-2-0-0), [Active Registry Monitor](https://www.devicelock.com/arm/) to monitor registry changes.

##### Windows services monitoring

- Malware usually install and run themselves as services.
- Use e.g. [Windows Service Manager (SrvMan)](https://sysprogs.com/legacy/tools/srvman/), [Process Hacker](https://processhacker.sourceforge.io/), [AnVir Task manager](https://www.anvir.com/) to monitor services

##### Startup programs monitoring

- Malware modify startup settings to execute themselves when system starts
- Check:
  - Startup registry keys
  - Automatically loaded drivers
  - `boot.ini` or `bcd` (`bootmgr`) entries
  - Services that starts automatically in `services.msc`
  - Startup folder
- Tools include [Autoruns for Windows](https://docs.microsoft.com/en-us/sysinternals/downloads/autoruns), [Autorun Organizer](https://www.chemtable.com/autorun-organizer.htm), [WinTools.net: Startup Manager](http://wintools.net/startup/index.html)

##### Event logs monitoring/analysis

- Analyze logs on IDS/IPS, web servers, authentication servers etc.
- In Windows you can use Event Viewer to see system, application and security logs
- Tools include [Loggly](https://www.loggly.com/), [SolarWinds Security Event Manager (SIEM)](https://www.solarwinds.com/security-event-manager), [Splunk](https://www.splunk.com/)

##### Installation monitoring

- See what has been modified during installation process
- Tools include [SysAnalyzer](http://sandsprite.com/iDef/SysAnalyzer/), [Mirekusoft Install Monitor](https://www.mirekusoft.com/), [Revo Uninstaller Pro](https://www.revouninstaller.com/)

##### Files and folder monitoring

- Scan system files for suspicious files and folders
- Tools include:
  - `Sigverif`
    - Built-in Windows tool
    - Identifies unsigned drivers
  - [Tripwire File Integrity Manager](https://www.tripwire.com/products/tripwire-file-integrity-manager)
  - [CSP File Integrity Checker](https://www.cspsecurity.com/solutions/compliance-and-file-monitoring/file-integrity-checker/).

##### Device drivers monitoring

- Malware installs with some infected drivers
- Drivers can be seen by: Run -> `msinfo32` -> Software Environment -> System Drivers
- Tools include [DriverView](https://www.nirsoft.net/utils/driverview.html), [Driver Booster](https://www.iobit.com/en/driver-booster.php)

##### Network traffic monitoring/analysis

- Includes capturing traffic to look for malware activity
- Tools for capturing and monitoring include: [Wireshark](https://www.wireshark.org/), [Capsa Network Analyzer](https://www.colasoft.com/capsa/)

##### DNS monitoring/resolution

- DNSChanger is a DNS hijacking Trojan that can point DNS entries toward malicious name servers.
- Use e.g. [DNSQuerySniffer](https://www.nirsoft.net/utils/dns_query_sniffer.html), [DNSstuff](https://www.dnsstuff.com/).

##### API calls monitoring

- Malware use Windows APIs to perform malicious task
- API call monitoring tools include [API Monitor](http://www.rohitab.com/apimonitor), [Runscope](https://www.runscope.com/)

##### System baselining

- Allows monitoring security configuration changes over time
- Flow
  1. Take snapshots before and then after malware execution.
  2. Compare the snapshots to understand changes made by the malware.

#### Unix integrity monitoring

- Display processes: `ps -ef`
  - `-e`: selects all processes
  - `-f`: switch provides a full listing

## Sandboxing

- Technique in which you create an isolated test environment
  - Allows secure experimentation
  - Nothing (no harm) can be spilled out of the environment.
    - If something happens, the damage is confined to that sandbox
- Examples
  - **Chrome web-browser**
    - Sandboxing through multi-process architecture.
    - One or more processes are assigned to run scripts of each site.
    - Each Chrome extension and app runs in its own process
  - **Virtual machines**
    - Good for testing / reverse engineering malware
    - E.g. YouTubers messing with scammers utilizes virtual machines, [video](https://www.youtube.com/watch?v=BQ3FD26Bv8c), [video](https://www.youtube.com/watch?v=vgYeDMwteZo)
    - 💡 Good hypervisor is important to ensure nothing goes out of the environment.
      - E.g. KVM (used by AWS) is good on AWS, and Hyper-V in Windows
        - KVM installation in Fedora: `dnf install @Virtualization` and then `virt-manager` to start a GUI.
      - VirtualBox is not as feature rich.
    - 💡 Make sure host environment is safe in first place
      - E.g. in Linux you can enable [Security-Enhanced Linux](https://en.wikipedia.org/wiki/Security-Enhanced_Linux) (SELinux).
        - Supported by Fedora, Debian, Ubuntu, used by default by Android.
        - `setenforce 1` to enable, `getenforce` to query status

## Anti-malware software

- Includes e.g. antivirus, anti-spyware, anti-trojans, anti-spamware, anti-phishing, and email scanners.
- Helps detecting, mitigating, preventing and repairing any damage by malware.
- Looks for behavior typical to viruses and give warnings.
- Looks for already known virus signatures and warns the user if a threat is found.
- E.g. Kaspersky, McAffee, AVG, Norton, Avira, Bitdefender

### Detection types

- **Signature-based**
  - Compare file hash and malware hash
  - ❗ Anything new or custom written will not be detected
- **Rule-based (behavior-based)**
  - 📝 Relies on differentiating expected vs anomalous behavior
  - Analyzes certain characteristics of a program.
    - E.g. application accessing user login file. Why?
  - Can utilize AI & ML to decide whether something is a malware.
- **Sandboxing**
  - Creates environment, lets program run and examines its behavior.
  - Good to find out behavior of e.g. self-modifying code, encrypted code.

## 📝 Virus detection methods

- **Scanning**
  - Scans malware for known signatures (characteristics)
  - ❗ Only known and predefined viruses can be detected
- **Integrity checking**
  - Verifies files against their recorded integrated data
- **Interception**
  - Intercepts the virus if it detect suspicious behavior (e.g. network access) and asks user if the user wants to continue.
  - Useful for logic bombs (only executed if certain conditions are met) or trojans
- **Code emulation**
  - Executes a virtual machine mimicking CPU and memory
  - Useful against encrypted, polymorphic or metamorphic viruses
- **Heuristic analysis**
  - Helps in detecting new or unknown viruses
  - **Static**: anti-virus decompiles and analyzes the binary
  - **Dynamic**: anti-virus runs code emulation to determine if the code is viral
  - Prone to many false positives

## Malware countermeasures

- Use up-to-date anti-virus, firewall and intrusion detection software with regular scans
- Block all unnecessary ports at the host and firewall.
- On Windows
  - Enable Windows Defender
  - Enable [Data Execution Prevention (DEP)](#data-execution-prevention-dep)
  - Run registry monitoring tools to find malicious registry entries added by the backdoor
- Enable [Address space layout randomization (ASLR)](#address-space-layout-randomization-aslr)
- Do not open files with more than one file type extension
- Use [anti-malware software](#anti-malware-software)
- Avoid accepting executables sent as messages or downloaded from untrusted sources.
- Inspect network packets using protocol monitoring tools

### Data Execution Prevention (DEP)

- 📝 Marks memory regions as non-executable, such that an attempt to execute machine code in these regions will cause an exception
- Executable space protection in Windows
- Read more on [Data Execution Prevention | Microsoft Docs](https://docs.microsoft.com/en-us/windows/win32/memory/data-execution-prevention)

### Address space layout randomization (ASLR)

- 📝 Prevents exploitation of memory corruption vulnerabilities.
- Involves randomly positioning the base address of an executable and the position of libraries, heap, and stack, in a process's address space
- Breaks assumptions that attackers could make about where programs and libraries would lie in memory at runtime
